==> fabrik_cli-1.1.0.tar.gz: fabrik_cli-1.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import pip

from setuptools import setup, find_packages
from pip.req import parse_requirements
import frojd_fabric_cli


if sys.argv[-1] == "publish":
    os.system("python setup.py sdist upload")
    sys.exit()

package_exclude = ("tests*", "examples*")
packages = find_packages(exclude=package_exclude)

# Install dependencies
requires = parse_requirements("requirements/install.txt",
                              session=pip.download.PipSession())
install_requires = [str(ir.req) for ir in requires]

requires = parse_requirements("requirements/tests.txt",
                              session=pip.download.PipSession())
tests_requires = [str(ir.req) for ir in requires]

# Convert markdown to rst
try:
    from pypandoc import convert
    long_description = convert("README.md", "rst")
except:
    long_description = ""


setup(
    name="fabrik_cli",
    version=frojd_fabric_cli.__version__,
    description=("CLI tool for scaffolding fabrik files "),
    long_description=long_description,
    author="Fröjd",
    author_email="martin.sandstrom@frojd.se",
    url="https://github.com/frojd/fabrik-cli",
    packages=packages,
    include_package_data=True,
    install_requires=install_requires,
    tests_require=tests_requires,
    license="MIT",
    zip_safe=False,
    entry_points={
        "console_scripts": [
            "fabrik = frojd_fabric_cli.scripts.init:main",
            "cleanup = frojd_fabric_cli.scripts.cleanup:main",
        ]
    },
)

==> fabrik_cli-1.1.2.tar.gz: fabrik_cli-1.1.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import pip

from setuptools import setup, find_packages
from pip.req import parse_requirements
import frojd_fabric_cli


if sys.argv[-1] == "publish":
    os.system("python setup.py sdist upload")
    sys.exit()

package_exclude = ("tests*", "examples*")
packages = find_packages(exclude=package_exclude)

# Install dependencies
requires = parse_requirements("requirements/install.txt",
                              session=pip.download.PipSession())
install_requires = [str(ir.req) for ir in requires]

requires = parse_requirements("requirements/tests.txt",
                              session=pip.download.PipSession())
tests_requires = [str(ir.req) for ir in requires]

# Convert markdown to rst
try:
    from pypandoc import convert
    long_description = convert("README.md", "rst")
except:
    long_description = ""


setup(
    name="fabrik_cli",
    version=frojd_fabric_cli.__version__,
    description=("CLI tool for scaffolding fabrik files "),
    long_description=long_description,
    author="Fröjd",
    author_email="martin.sandstrom@frojd.se",
    url="https://github.com/frojd/fabrik-cli",
    packages=packages,
    include_package_data=True,
    install_requires=install_requires,
    tests_require=tests_requires,
    license="MIT",
    zip_safe=False,
    entry_points={
        "console_scripts": [
            "fabrik-cli = frojd_fabric_cli.scripts.init:main",
            "cleanup = frojd_fabric_cli.scripts.cleanup:main",
        ]
    },
)
